# pygments-periwinkle-lexer

Пакет для [Pygments](https://pygments.org/), який додає підсвічування синтаксису для мови програмування [Барвінок](https://github.com/periwinkle-lang)

## Інсталяція

Встановити пакет можна через pip:

```
pip install pygments-periwinkle-lexer
```

## Ліцензія
[MIT](LICENCE)
